import { Json } from '../util/index.js';
import { Identifier } from './Identifier.js';
export class BlockState {
    properties;
    static AIR = new BlockState(Identifier.create('air'));
    static STONE = new BlockState(Identifier.create('stone'));
    static WATER = new BlockState(Identifier.create('water'), { level: '0' });
    static LAVA = new BlockState(Identifier.create('lava'), { level: '0' });
    name;
    constructor(name, properties = {}) {
        this.properties = properties;
        this.name = typeof name === 'string' ? Identifier.parse(name) : name;
    }
    getName() {
        return this.name;
    }
    getProperties() {
        return this.properties;
    }
    getProperty(key) {
        return this.properties[key];
    }
    isFluid() {
        return this.is(BlockState.WATER) || this.is(BlockState.LAVA);
    }
    equals(other) {
        if (!this.name.equals(other.name)) {
            return false;
        }
        return Object.keys(this.properties).every(p => {
            return other.properties[p] === this.properties[p];
        });
    }
    is(other) {
        return this.name.equals(other.name);
    }
    toString() {
        if (Object.keys(this.properties).length === 0) {
            return this.name.toString();
        }
        return `${this.name.toString()}[${Object.entries(this.properties).map(([k, v]) => k + '=' + v).join(',')}]`;
    }
    static fromNbt(nbt) {
        const name = Identifier.parse(nbt.getString('Name'));
        const properties = nbt.getCompound('Properties')
            .map((key, value) => [key, value.getAsString()]);
        return new BlockState(name, properties);
    }
    static fromJson(obj) {
        const root = Json.readObject(obj) ?? {};
        const name = Identifier.parse(Json.readString(root.Name) ?? BlockState.STONE.name.toString());
        const properties = Json.readMap(root.Properties, p => Json.readString(p) ?? '');
        return new BlockState(name, properties);
    }
}
//# sourceMappingURL=BlockState.js.map