import { Identifier } from '../Identifier.js';
import { Registry } from '../Registry.js';
import { MobEffectInstance } from './MobEffectInstance.js';
export declare type ItemRarity = 'common' | 'uncommon' | 'rare' | 'epic';
export interface SpawnEggProperties {
    entityType: string;
    background: number;
    highlight: number;
}
export interface FoodProperties {
    nutrition: number;
    saturationModifier: number;
    isMeat: boolean;
    canAlwaysEat: boolean;
    fastFood: boolean;
    effects: [MobEffectInstance, number][];
}
export declare type EquipmentSlot = 'mainhand' | 'offhand' | 'feet' | 'legs' | 'chest' | 'head';
export declare type ArmorMaterial = 'leather' | 'chainmail' | 'iron' | 'gold' | 'diamond' | 'turtle' | 'netherite';
export interface ArmorProperties {
    slot: EquipmentSlot;
    material: ArmorMaterial;
    defense: number;
    toughness: number;
    knockbackResistance: number;
}
export declare type ItemTier = 'wood' | 'stone' | 'iron' | 'diamond' | 'gold' | 'netherite';
export interface TieredProperties {
    tier: ItemTier;
    level: number;
    speed: number;
    damage: number;
    isWeapon: boolean;
    isDigger: boolean;
    isAxe: boolean;
}
export interface Item {
    readonly id: Identifier;
    readonly rarity: ItemRarity;
    readonly stack: number;
    readonly durability?: number;
    readonly enchantmentValue?: number;
    readonly fireResistant?: boolean;
    readonly wearable?: boolean;
    readonly vanishable?: boolean;
    readonly craftRemainder?: Item;
    readonly spawnEgg?: SpawnEggProperties;
    readonly food?: FoodProperties;
    readonly armor?: ArmorProperties;
    readonly tiered?: TieredProperties;
}
export declare namespace Item {
    const REGISTRY: Registry<Item>;
    function get(arg: string | Identifier): Item;
}
export declare namespace Items {
    const AIR: Item;
    const CARVED_PUMPKIN: Item;
    const SADDLE: Item;
    const MINECART: Item;
    const CHEST_MINECART: Item;
    const FURNACE_MINECART: Item;
    const TNT_MINECART: Item;
    const HOPPER_MINECART: Item;
    const CARROT_ON_A_STICK: Item;
    const WARPED_FUNGUS_ON_A_STICK: Item;
    const ELYTRA: Item;
    const OAK_BOAT: Item;
    const OAK_CHEST_BOAT: Item;
    const SPRUCE_BOAT: Item;
    const SPRUCE_CHEST_BOAT: Item;
    const BIRCH_BOAT: Item;
    const BIRCH_CHEST_BOAT: Item;
    const JUNGLE_BOAT: Item;
    const JUNGLE_CHEST_BOAT: Item;
    const ACACIA_BOAT: Item;
    const ACACIA_CHEST_BOAT: Item;
    const DARK_OAK_BOAT: Item;
    const DARK_OAK_CHEST_BOAT: Item;
    const MANGROVE_BOAT: Item;
    const MANGROVE_CHEST_BOAT: Item;
    const BAMBOO_RAFT: Item;
    const BAMBOO_CHEST_RAFT: Item;
    const STRUCTURE_BLOCK: Item;
    const JIGSAW: Item;
    const TURTLE_HELMET: Item;
    const FLINT_AND_STEEL: Item;
    const APPLE: Item;
    const BOW: Item;
    const NETHERITE_INGOT: Item;
    const NETHERITE_SCRAP: Item;
    const WOODEN_SWORD: Item;
    const WOODEN_SHOVEL: Item;
    const WOODEN_PICKAXE: Item;
    const WOODEN_AXE: Item;
    const WOODEN_HOE: Item;
    const STONE_SWORD: Item;
    const STONE_SHOVEL: Item;
    const STONE_PICKAXE: Item;
    const STONE_AXE: Item;
    const STONE_HOE: Item;
    const GOLDEN_SWORD: Item;
    const GOLDEN_SHOVEL: Item;
    const GOLDEN_PICKAXE: Item;
    const GOLDEN_AXE: Item;
    const GOLDEN_HOE: Item;
    const IRON_SWORD: Item;
    const IRON_SHOVEL: Item;
    const IRON_PICKAXE: Item;
    const IRON_AXE: Item;
    const IRON_HOE: Item;
    const DIAMOND_SWORD: Item;
    const DIAMOND_SHOVEL: Item;
    const DIAMOND_PICKAXE: Item;
    const DIAMOND_AXE: Item;
    const DIAMOND_HOE: Item;
    const NETHERITE_SWORD: Item;
    const NETHERITE_SHOVEL: Item;
    const NETHERITE_PICKAXE: Item;
    const NETHERITE_AXE: Item;
    const NETHERITE_HOE: Item;
    const MUSHROOM_STEW: Item;
    const BREAD: Item;
    const LEATHER_HELMET: Item;
    const LEATHER_CHESTPLATE: Item;
    const LEATHER_LEGGINGS: Item;
    const LEATHER_BOOTS: Item;
    const CHAINMAIL_HELMET: Item;
    const CHAINMAIL_CHESTPLATE: Item;
    const CHAINMAIL_LEGGINGS: Item;
    const CHAINMAIL_BOOTS: Item;
    const IRON_HELMET: Item;
    const IRON_CHESTPLATE: Item;
    const IRON_LEGGINGS: Item;
    const IRON_BOOTS: Item;
    const DIAMOND_HELMET: Item;
    const DIAMOND_CHESTPLATE: Item;
    const DIAMOND_LEGGINGS: Item;
    const DIAMOND_BOOTS: Item;
    const GOLDEN_HELMET: Item;
    const GOLDEN_CHESTPLATE: Item;
    const GOLDEN_LEGGINGS: Item;
    const GOLDEN_BOOTS: Item;
    const NETHERITE_HELMET: Item;
    const NETHERITE_CHESTPLATE: Item;
    const NETHERITE_LEGGINGS: Item;
    const NETHERITE_BOOTS: Item;
    const PORKCHOP: Item;
    const COOKED_PORKCHOP: Item;
    const GOLDEN_APPLE: Item;
    const ENCHANTED_GOLDEN_APPLE: Item;
    const OAK_SIGN: Item;
    const SPRUCE_SIGN: Item;
    const BIRCH_SIGN: Item;
    const JUNGLE_SIGN: Item;
    const ACACIA_SIGN: Item;
    const DARK_OAK_SIGN: Item;
    const MANGROVE_SIGN: Item;
    const BAMBOO_SIGN: Item;
    const CRIMSON_SIGN: Item;
    const WARPED_SIGN: Item;
    const OAK_HANGING_SIGN: Item;
    const SPRUCE_HANGING_SIGN: Item;
    const BIRCH_HANGING_SIGN: Item;
    const JUNGLE_HANGING_SIGN: Item;
    const ACACIA_HANGING_SIGN: Item;
    const DARK_OAK_HANGING_SIGN: Item;
    const MANGROVE_HANGING_SIGN: Item;
    const BAMBOO_HANGING_SIGN: Item;
    const CRIMSON_HANGING_SIGN: Item;
    const WARPED_HANGING_SIGN: Item;
    const BUCKET: Item;
    const WATER_BUCKET: Item;
    const LAVA_BUCKET: Item;
    const POWDER_SNOW_BUCKET: Item;
    const SNOWBALL: Item;
    const MILK_BUCKET: Item;
    const PUFFERFISH_BUCKET: Item;
    const SALMON_BUCKET: Item;
    const COD_BUCKET: Item;
    const TROPICAL_FISH_BUCKET: Item;
    const AXOLOTL_BUCKET: Item;
    const TADPOLE_BUCKET: Item;
    const BOOK: Item;
    const EGG: Item;
    const COMPASS: Item;
    const BUNDLE: Item;
    const FISHING_ROD: Item;
    const SPYGLASS: Item;
    const COD: Item;
    const SALMON: Item;
    const TROPICAL_FISH: Item;
    const PUFFERFISH: Item;
    const COOKED_COD: Item;
    const COOKED_SALMON: Item;
    const CAKE: Item;
    const WHITE_BED: Item;
    const ORANGE_BED: Item;
    const MAGENTA_BED: Item;
    const LIGHT_BLUE_BED: Item;
    const YELLOW_BED: Item;
    const LIME_BED: Item;
    const PINK_BED: Item;
    const GRAY_BED: Item;
    const LIGHT_GRAY_BED: Item;
    const CYAN_BED: Item;
    const PURPLE_BED: Item;
    const BLUE_BED: Item;
    const BROWN_BED: Item;
    const GREEN_BED: Item;
    const RED_BED: Item;
    const BLACK_BED: Item;
    const COOKIE: Item;
    const SHEARS: Item;
    const MELON_SLICE: Item;
    const DRIED_KELP: Item;
    const BEEF: Item;
    const COOKED_BEEF: Item;
    const CHICKEN: Item;
    const COOKED_CHICKEN: Item;
    const ROTTEN_FLESH: Item;
    const ENDER_PEARL: Item;
    const POTION: Item;
    const GLASS_BOTTLE: Item;
    const SPIDER_EYE: Item;
    const ALLAY_SPAWN_EGG: Item;
    const AXOLOTL_SPAWN_EGG: Item;
    const BAT_SPAWN_EGG: Item;
    const BEE_SPAWN_EGG: Item;
    const BLAZE_SPAWN_EGG: Item;
    const CAT_SPAWN_EGG: Item;
    const CAMEL_SPAWN_EGG: Item;
    const CAVE_SPIDER_SPAWN_EGG: Item;
    const CHICKEN_SPAWN_EGG: Item;
    const COD_SPAWN_EGG: Item;
    const COW_SPAWN_EGG: Item;
    const CREEPER_SPAWN_EGG: Item;
    const DOLPHIN_SPAWN_EGG: Item;
    const DONKEY_SPAWN_EGG: Item;
    const DROWNED_SPAWN_EGG: Item;
    const ELDER_GUARDIAN_SPAWN_EGG: Item;
    const ENDER_DRAGON_SPAWN_EGG: Item;
    const ENDERMAN_SPAWN_EGG: Item;
    const ENDERMITE_SPAWN_EGG: Item;
    const EVOKER_SPAWN_EGG: Item;
    const FOX_SPAWN_EGG: Item;
    const FROG_SPAWN_EGG: Item;
    const GHAST_SPAWN_EGG: Item;
    const GLOW_SQUID_SPAWN_EGG: Item;
    const GOAT_SPAWN_EGG: Item;
    const GUARDIAN_SPAWN_EGG: Item;
    const HOGLIN_SPAWN_EGG: Item;
    const HORSE_SPAWN_EGG: Item;
    const HUSK_SPAWN_EGG: Item;
    const IRON_GOLEM_SPAWN_EGG: Item;
    const LLAMA_SPAWN_EGG: Item;
    const MAGMA_CUBE_SPAWN_EGG: Item;
    const MOOSHROOM_SPAWN_EGG: Item;
    const MULE_SPAWN_EGG: Item;
    const OCELOT_SPAWN_EGG: Item;
    const PANDA_SPAWN_EGG: Item;
    const PARROT_SPAWN_EGG: Item;
    const PHANTOM_SPAWN_EGG: Item;
    const PIG_SPAWN_EGG: Item;
    const PIGLIN_SPAWN_EGG: Item;
    const PIGLIN_BRUTE_SPAWN_EGG: Item;
    const PILLAGER_SPAWN_EGG: Item;
    const POLAR_BEAR_SPAWN_EGG: Item;
    const PUFFERFISH_SPAWN_EGG: Item;
    const RABBIT_SPAWN_EGG: Item;
    const RAVAGER_SPAWN_EGG: Item;
    const SALMON_SPAWN_EGG: Item;
    const SHEEP_SPAWN_EGG: Item;
    const SHULKER_SPAWN_EGG: Item;
    const SILVERFISH_SPAWN_EGG: Item;
    const SKELETON_SPAWN_EGG: Item;
    const SKELETON_HORSE_SPAWN_EGG: Item;
    const SLIME_SPAWN_EGG: Item;
    const SNOW_GOLEM_SPAWN_EGG: Item;
    const SPIDER_SPAWN_EGG: Item;
    const SQUID_SPAWN_EGG: Item;
    const STRAY_SPAWN_EGG: Item;
    const STRIDER_SPAWN_EGG: Item;
    const TADPOLE_SPAWN_EGG: Item;
    const TRADER_LLAMA_SPAWN_EGG: Item;
    const TROPICAL_FISH_SPAWN_EGG: Item;
    const TURTLE_SPAWN_EGG: Item;
    const VEX_SPAWN_EGG: Item;
    const VILLAGER_SPAWN_EGG: Item;
    const VINDICATOR_SPAWN_EGG: Item;
    const WANDERING_TRADER_SPAWN_EGG: Item;
    const WARDEN_SPAWN_EGG: Item;
    const WITCH_SPAWN_EGG: Item;
    const WITHER_SPAWN_EGG: Item;
    const WITHER_SKELETON_SPAWN_EGG: Item;
    const WOLF_SPAWN_EGG: Item;
    const ZOGLIN_SPAWN_EGG: Item;
    const ZOMBIE_SPAWN_EGG: Item;
    const ZOMBIE_HORSE_SPAWN_EGG: Item;
    const ZOMBIE_VILLAGER_SPAWN_EGG: Item;
    const ZOMBIFIED_PIGLIN_SPAWN_EGG: Item;
    const EXPERIENCE_BOTTLE: Item;
    const WRITABLE_BOOK: Item;
    const WRITTEN_BOOK: Item;
    const CARROT: Item;
    const POTATO: Item;
    const BAKED_POTATO: Item;
    const POISONOUS_POTATO: Item;
    const GOLDEN_CARROT: Item;
    const SKELETON_SKULL: Item;
    const WITHER_SKELETON_SKULL: Item;
    const PLAYER_HEAD: Item;
    const ZOMBIE_HEAD: Item;
    const CREEPER_HEAD: Item;
    const DRAGON_HEAD: Item;
    const PIGLIN_HEAD: Item;
    const NETHER_STAR: Item;
    const PUMPKIN_PIE: Item;
    const ENCHANTED_BOOK: Item;
    const RABBIT: Item;
    const COOKED_RABBIT: Item;
    const RABBIT_STEW: Item;
    const ARMOR_STAND: Item;
    const IRON_HORSE_ARMOR: Item;
    const GOLDEN_HORSE_ARMOR: Item;
    const DIAMOND_HORSE_ARMOR: Item;
    const LEATHER_HORSE_ARMOR: Item;
    const COMMAND_BLOCK_MINECART: Item;
    const MUTTON: Item;
    const COOKED_MUTTON: Item;
    const WHITE_BANNER: Item;
    const ORANGE_BANNER: Item;
    const MAGENTA_BANNER: Item;
    const LIGHT_BLUE_BANNER: Item;
    const YELLOW_BANNER: Item;
    const LIME_BANNER: Item;
    const PINK_BANNER: Item;
    const GRAY_BANNER: Item;
    const LIGHT_GRAY_BANNER: Item;
    const CYAN_BANNER: Item;
    const PURPLE_BANNER: Item;
    const BLUE_BANNER: Item;
    const BROWN_BANNER: Item;
    const GREEN_BANNER: Item;
    const RED_BANNER: Item;
    const BLACK_BANNER: Item;
    const END_CRYSTAL: Item;
    const CHORUS_FRUIT: Item;
    const BEETROOT: Item;
    const BEETROOT_SOUP: Item;
    const DRAGON_BREATH: Item;
    const SPLASH_POTION: Item;
    const LINGERING_POTION: Item;
    const SHIELD: Item;
    const TOTEM_OF_UNDYING: Item;
    const KNOWLEDGE_BOOK: Item;
    const DEBUG_STICK: Item;
    const MUSIC_DISC_13: Item;
    const MUSIC_DISC_CAT: Item;
    const MUSIC_DISC_BLOCKS: Item;
    const MUSIC_DISC_CHIRP: Item;
    const MUSIC_DISC_FAR: Item;
    const MUSIC_DISC_MALL: Item;
    const MUSIC_DISC_MELLOHI: Item;
    const MUSIC_DISC_STAL: Item;
    const MUSIC_DISC_STRAD: Item;
    const MUSIC_DISC_WARD: Item;
    const MUSIC_DISC_11: Item;
    const MUSIC_DISC_WAIT: Item;
    const MUSIC_DISC_OTHERSIDE: Item;
    const MUSIC_DISC_5: Item;
    const MUSIC_DISC_PIGSTEP: Item;
    const TRIDENT: Item;
    const HEART_OF_THE_SEA: Item;
    const CROSSBOW: Item;
    const SUSPICIOUS_STEW: Item;
    const FLOWER_BANNER_PATTERN: Item;
    const CREEPER_BANNER_PATTERN: Item;
    const SKULL_BANNER_PATTERN: Item;
    const MOJANG_BANNER_PATTERN: Item;
    const GLOBE_BANNER_PATTERN: Item;
    const PIGLIN_BANNER_PATTERN: Item;
    const GOAT_HORN: Item;
    const SWEET_BERRIES: Item;
    const GLOW_BERRIES: Item;
    const HONEY_BOTTLE: Item;
}
//# sourceMappingURL=Item.d.ts.map