import { Identifier, Registry } from '../core/index.js';
import { NoiseParameters } from '../math/index.js';
import { DensityFunction } from './DensityFunction.js';
import { NoiseGeneratorSettings } from './NoiseGeneratorSettings.js';
export var WorldgenRegistries;
(function (WorldgenRegistries) {
    WorldgenRegistries.NOISE = register('worldgen/noise', NoiseParameters.fromJson);
    WorldgenRegistries.DENSITY_FUNCTION = register('worldgen/density_function', obj => DensityFunction.fromJson(obj));
    WorldgenRegistries.NOISE_SETTINGS = register('worldgen/noise_settings', NoiseGeneratorSettings.fromJson);
    function register(name, parser) {
        const registry = new Registry(Identifier.create(name), parser);
        Registry.REGISTRY.register(registry.key, registry);
        return registry;
    }
    WorldgenRegistries.SURFACE_NOISE = createNoise('surface', -6, [1, 1, 1]);
    WorldgenRegistries.SURFACE_SECONDARY_NOISE = createNoise('surface_secondary', -6, [1, 1, 0, 1]);
    function createNoise(name, firstOctave, amplitudes) {
        return WorldgenRegistries.NOISE.register(Identifier.create(name), NoiseParameters.create(firstOctave, amplitudes), true);
    }
})(WorldgenRegistries || (WorldgenRegistries = {}));
//# sourceMappingURL=WorldgenRegistries.js.map